# About
KahootConnect is a Kahoot API written in python, that Kahoot can't take down 🤡 #REForever

# Installation

`pip install -U KahootConnect`
or, clone the repo and
`python3 -m pip install -e ./KahootConnect`

# Usage

Work In Progress!

# Documentation:
Work In Progress!

# Kahoot Docs (OUTDATED)
 [Need api docs?](KahootProtocol.md)
 [More detailed docs?](KahootProtocolDetailed.md)
